@@ -132,6 +132,10 @@ def read_null(
     return decoder.read_null()
 
 
+def skip_null(decoder, writer_schema=None, named_schemas=None):
+    decoder.read_null()
+
+
 def read_boolean(
     decoder,
     writer_schema=None,
@@ -142,6 +146,10 @@ def read_boolean(
     return decoder.read_boolean()
 
 
+def skip_boolean(decoder, writer_schema=None, named_schemas=None):
+    decoder.read_boolean()
+
+
 def read_timestamp_millis(data, writer_schema=None, reader_schema=None):
     # Cannot use datetime.fromtimestamp: https://bugs.python.org/issue36439
     return epoch + timedelta(microseconds=data * 1000)
@@ -198,6 +206,10 @@ def read_int(
     return decoder.read_int()
 
 
+def skip_int(decoder, writer_schema=None, named_schemas=None):
+    decoder.read_int()
+
+
 def read_long(
     decoder,
     writer_schema=None,
@@ -208,6 +220,10 @@ def read_long(
     return decoder.read_long()
 
 
+def skip_long(decoder, writer_schema=None, named_schemas=None):
+    decoder.read_long()
+
+
 def read_float(
     decoder,
     writer_schema=None,
@@ -218,6 +234,10 @@ def read_float(
     return decoder.read_float()
 
 
+def skip_float(decoder, writer_schema=None, named_schemas=None):
+    decoder.read_float()
+
+
 def read_double(
     decoder,
     writer_schema=None,
@@ -228,6 +248,10 @@ def read_double(
     return decoder.read_double()
 
 
+def skip_double(decoder, writer_schema=None, named_schemas=None):
+    decoder.read_double()
+
+
 def read_bytes(
     decoder,
     writer_schema=None,
@@ -238,6 +262,10 @@ def read_bytes(
     return decoder.read_bytes()
 
 
+def skip_bytes(decoder, writer_schema=None, named_schemas=None):
+    decoder.read_bytes()
+
+
 def read_utf8(
     decoder,
     writer_schema=None,
@@ -248,6 +276,10 @@ def read_utf8(
     return decoder.read_utf8()
 
 
+def skip_utf8(decoder, writer_schema=None, named_schemas=None):
+    decoder.read_utf8()
+
+
 def read_fixed(
     decoder,
     writer_schema,
@@ -259,6 +291,11 @@ def read_fixed(
     return decoder.read_fixed(size)
 
 
+def skip_fixed(decoder, writer_schema, named_schemas=None):
+    size = writer_schema["size"]
+    decoder.read_fixed(size)
+
+
 def read_enum(
     decoder,
     writer_schema,
@@ -278,6 +315,10 @@ def read_enum(
     return symbol
 
 
+def skip_enum(decoder, writer_schema, named_schemas):
+    decoder.read_enum()
+
+
 def read_array(
     decoder,
     writer_schema,
@@ -321,6 +362,15 @@ def read_array(
     return read_items
 
 
+def skip_array(decoder, writer_schema, named_schemas):
+    decoder.read_array_start()
+
+    for item in decoder.iter_array():
+        skip_data(decoder, writer_schema["items"], named_schemas)
+
+    decoder.read_array_end()
+
+
 def read_map(
     decoder,
     writer_schema,
@@ -363,6 +413,16 @@ def read_map(
     return read_items
 
 
+def skip_map(decoder, writer_schema, named_schemas):
+    decoder.read_map_start()
+
+    for item in decoder.iter_map():
+        decoder.read_utf8()
+        skip_data(decoder, writer_schema["values"], named_schemas)
+
+    decoder.read_map_end()
+
+
 def read_union(
     decoder,
     writer_schema,
@@ -419,6 +479,12 @@ def read_union(
             return read_data(decoder, idx_schema, named_schemas)
 
 
+def skip_union(decoder, writer_schema, named_schemas):
+    # schema resolution
+    index = decoder.read_index()
+    skip_data(decoder, writer_schema[index], named_schemas)
+
+
 def read_record(
     decoder,
     writer_schema,
@@ -472,14 +538,7 @@ def read_record(
                     return_record_name,
                 )
             else:
-                # should implement skip
-                read_data(
-                    decoder,
-                    field["type"],
-                    named_schemas,
-                    field["type"],
-                    return_record_name,
-                )
+                skip_data(decoder, field["type"], named_schemas)
 
         # fill in default values
         if len(readers_field_dict) > len(record):
@@ -495,6 +554,11 @@ def read_record(
     return record
 
 
+def skip_record(decoder, writer_schema, named_schemas):
+    for field in writer_schema["fields"]:
+        skip_data(decoder, field["type"], named_schemas)
+
+
 LOGICAL_READERS = {
     "long-timestamp-millis": read_timestamp_millis,
     "long-timestamp-micros": read_timestamp_micros,
@@ -526,6 +590,26 @@ READERS = {
     "request": read_record,
 }
 
+SKIPS = {
+    "null": skip_null,
+    "boolean": skip_boolean,
+    "string": skip_utf8,
+    "int": skip_int,
+    "long": skip_long,
+    "float": skip_float,
+    "double": skip_double,
+    "bytes": skip_bytes,
+    "fixed": skip_fixed,
+    "enum": skip_enum,
+    "array": skip_array,
+    "map": skip_map,
+    "union": skip_union,
+    "error_union": skip_union,
+    "record": skip_record,
+    "error": skip_record,
+    "request": skip_record,
+}
+
 
 def maybe_promote(data, writer_type, reader_type):
     if writer_type == "int":
@@ -590,6 +674,16 @@ def read_data(
         )
 
 
+def skip_data(decoder, writer_schema, named_schemas):
+    record_type = extract_record_type(writer_schema)
+
+    reader_fn = SKIPS.get(record_type)
+    if reader_fn:
+        reader_fn(decoder, writer_schema, named_schemas)
+    else:
+        skip_data(decoder, named_schemas[record_type], named_schemas)
+
+
 def skip_sync(fo, sync_marker):
     """Skip an expected sync marker, complaining if it doesn't match"""
     if fo.read(SYNC_SIZE) != sync_marker:
@@ -815,7 +909,7 @@ class Block:
         )
 
 
-class file_reader(object):
+class file_reader:
     def __init__(self, fo_or_decoder, reader_schema=None, return_record_name=False):
         if isinstance(fo_or_decoder, AvroJSONDecoder):
             self.decoder = fo_or_decoder
